@@ -1,10 +1,9 @@
 from collections import namedtuple
 
-Sprite = namedtuple('Sprite', ['img', 'u', 'v', 'w', 'h', 'colkey'])
+Sprite = namedtuple("Sprite", ["img", "u", "v", "w", "h", "colkey"])
 
 
 class Tile:
-
     def __init__(self, x, y, sprite):
         self.x = x
         self.y = y
